@@ -43,7 +43,9 @@ class Client():
             verbose         :   Required (bool) - If True, prints information about code execution
             divider         :   Optional (str) - String delimiter for all name keys generated                    
         Returns:
-            List of errors from data row upload - if successful, is an empty list
+            A dictionary with "upload_results" and "conversion_errors" keys
+            - "upload_results" key pertains to the results of the data row upload itself
+            - "conversion_errors" key pertains to any errors related to data row conversion
         """    
         
         # Ensure all your metadata_index keys are metadata fields in Labelbox and that your Pandas DataFrame has all the right columns
@@ -52,27 +54,33 @@ class Client():
             get_unique_values_function=connector.get_unique_values_function, metadata_index=metadata_index, verbose=verbose
         )
         
-        # If df returns False, the sync failed
+        # If df returns False, the sync failed - terminate the upload
         if type(df) == bool:
-            return None   
+            return {"upload_results" : [], "conversion_errors" : []}
         
         # Create a dictionary where {key=global_key : value=labelbox_upload_dictionary} - this is unique to Pandas
-        result, global_key_to_upload_dict = connector.create_upload_dict(
+        global_key_to_upload_dict, conversion_errors = connector.create_upload_dict(
             df=df, lb_client=self.lb_client, base_client=self.base_client,
             row_data_col=row_data_col, global_key_col=global_key_col, external_id_col=external_id_col, 
             metadata_index=metadata_index, local_files=local_files, divider=divider, verbose=verbose
         )
         
-        if not result:
-            return global_key_to_upload_dict
+        # If there are conversion errors, let the user know; if there are no successful conversions, terminate the upload
+        if conversion_errors:
+            print(f'There were {len(conversion_errors)} errors in creating your upload list - the second return value will be a list of errors.')
+            if global_key_to_upload_dict:
+                print(f'Data row upload will continue - the first return value will be data row upload results')
+            else:
+                print(f'Data row upload will not continue')  
+                return {"upload_results" : [], "conversion_errors" : errors}
                 
         # Upload your data rows to Labelbox
         upload_results = self.base_client.batch_create_data_rows(
             dataset=lb_dataset, global_key_to_upload_dict=global_key_to_upload_dict, 
             skip_duplicates=skip_duplicates, divider=divider, verbose=verbose
         )
-
-        return upload_results
+        
+        return {"upload_results" : upload_results, "conversion_errors" : conversion_errors}
     
     # def upsert_table_metadata():
     #     return table
