@@ -20,7 +20,7 @@ def create_upload_dict(df:pandas.core.frame.DataFrame, lb_client:Client, base_cl
         divider         :   Optional (str) - String delimiter for all name keys generated
         verbose         :   Optional (bool) - If True, prints information about code execution
     Returns:
-        Two values - a success value, and a dictinoary where {key=global_key : value = {"row_data", "global_key", "external_id", "metadata_fields"}}
+        Two values - a success value, and a dictionary where {key=global_key : value = {"row_data", "global_key", "external_id", "metadata_fields"}}
     """    
     if verbose:
         print(f'Creating upload list - {len(df)} rows in Pandas DataFrame')
@@ -30,7 +30,7 @@ def create_upload_dict(df:pandas.core.frame.DataFrame, lb_client:Client, base_cl
     metadata_name_key_to_schema = base_client.get_metadata_schema_to_name_key(lb_mdo=False, divider=divider, invert=True) 
     global_key_to_upload_dict = {}
     with ThreadPoolExecutor(max_workers=8) as exc:
-        failed_global_keys = []
+        errors = []
         futures = []
         if verbose:
             print(f'Submitting data rows...')
@@ -40,25 +40,20 @@ def create_upload_dict(df:pandas.core.frame.DataFrame, lb_client:Client, base_cl
             print(f'Processing data rows...')
             for f in tqdm(as_completed(futures)):
                 res = f.result()
-                if type(res)==dict:
-                    global_key_to_upload_dict[str(res["global_key"])] = res    
+                if res['error']:
+                    errors.append(res)
                 else:
-                    failed_global_keys.append(res)
+                    global_key_to_upload_dict[str(res["global_key"])] = res    
         else:
             for f in as_completed(futures):
                 res = f.result()
-                if type(res)==dict:
-                    global_key_to_upload_dict[str(res["global_key"])] = res    
+                if res['error']:
+                    errors.append(res)
                 else:
-                    failed_global_keys.append(res)             
+                    global_key_to_upload_dict[str(res["global_key"])] = res       
     if verbose:
         print(f'Generated upload list - {len(global_key_to_upload_dict)} data rows to upload')
-    if failed_global_keys:
-        if global_key_to_upload_dict:
-            print(f'There were {len(failed_global_keys)} errors in creating your upload list - upload will continue and return a list of failed global keys')
-        else:
-            print(f'There were {len(failed_global_keys)} errors in creating your upload list - upload will not continue')
-    return global_key_to_upload_dict, failed_global_keys
+    return global_key_to_upload_dict, errors
   
 def create_data_rows(lb_client:Client, base_client:baseClient, row:pandas.core.series.Series,
                      metadata_name_key_to_schema:dict, metadata_schema_to_name_key:dict, row_data_col:str,
@@ -95,9 +90,9 @@ def create_data_rows(lb_client:Client, base_client:baseClient, row:pandas.core.s
                     metadata_fields.append({"schema_id" : metadata_name_key_to_schema[metadata_field_name], "value" : input_metadata})
                 else:
                     continue
-        return_value = {"row_data":row_data,"global_key":str(row[global_key_col]),"external_id":str(row[external_id_col]),"metadata_fields":metadata_fields}                                 
+        return_value = {"error" : None, "result" : {"row_data":row_data,"global_key":str(row[global_key_col]),"external_id":str(row[external_id_col]),"metadata_fields":metadata_fields}}
     except Exception as e:
-        return_value = [str(row[global_key_col]), e]
+        return_value = {"error" : e, "result" : None}
     return return_value
   
 def get_columns_function(df):
